@@ -5,13 +5,14 @@ use strict;
 
 use version; our $VERSION = qv('1.0.0');
 
+use IO::Stream::const;
+
 # update DEPENDENCIES in POD & Makefile.PL & README
 use Scalar::Util qw( weaken );
 use Socket qw( inet_aton sockaddr_in );
 use EV;
-use EV::ADNS;
+BEGIN { if (!WIN32) { eval 'use EV::ADNS; 1' or die $@ }} ## no critic
 
-use IO::Stream::const;
 
 
 # States:
@@ -78,13 +79,22 @@ sub resolve {
     if ($host =~ /\A\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}\z/xms) {
         $cb->($plugin, $host);
     }
+    elsif (WIN32) {
+        my $iaddr = inet_aton($host);
+        if ($iaddr) {
+            $cb->($plugin, join q{.}, unpack 'C4', $iaddr);
+        }
+        else {
+            $plugin->{_master}->EVENT(0, EDNSNXDOMAIN);
+        }
+    }
     else {
         weaken($plugin);
         # WARNING   ADNS has own timeouts, so we don't setup own here.
-        EV::ADNS::submit $host, EV::ADNS::r_addr, 0, sub {
+        EV::ADNS::submit $host, EV::ADNS::r_addr(), 0, sub {
             my ($status, undef, @a) = @_;
             return if !$plugin;
-            if ($status == EV::ADNS::s_ok) {
+            if ($status == EV::ADNS::s_ok()) {
                 $cb->($plugin, @a);
             }
             else {
@@ -99,9 +109,9 @@ sub resolve {
 sub adns2err {
     my ($status) = @_;
     return
-        $status == EV::ADNS::s_timeout    ? ETORESOLVE
-      : $status == EV::ADNS::s_nxdomain   ? EDNSNXDOMAIN
-      : $status == EV::ADNS::s_nodata     ? EDNSNODATA
+        $status == EV::ADNS::s_timeout()  ? ETORESOLVE
+      : $status == EV::ADNS::s_nxdomain() ? EDNSNXDOMAIN
+      : $status == EV::ADNS::s_nodata()   ? EDNSNODATA
       :                                     EDNS
 }
 
